OC.L10N.register(
    "files_trashbin",
    {
    "Couldn't delete %s permanently" : "Nie można trwale usunąć %s",
    "Couldn't restore %s" : "Nie można przywrócić %s",
    "Deleted files" : "Usunięte pliki",
    "Restore" : "Przywróć",
    "Delete" : "Usuń",
    "Delete permanently" : "Trwale usuń",
    "Error" : "Błąd",
    "restored" : "przywrócony",
    "No deleted files" : "Brak skasowanych plików",
    "You will be able to recover deleted files from here" : "Możesz przywrócić skasowane pliki stąd",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Select all" : "Wybierz wszystko",
    "Name" : "Nazwa",
    "Deleted" : "Usunięte"
},
"nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
